@@ -38,7 +38,7 @@ def gmin():
         # execute GMIN binary as defined by setup.py for correct OS
         subprocess.call('GMIN', stdout=f)
     else:
-        print('Data or oords file are missing')		
+        print('Data or coords file are missing')		
 
 #run OPTIM
 def optim(outfile='optim_output.txt'):
